@@ -28,7 +28,7 @@
 #ifndef GUM_SDYNA_H
 #define GUM_SDYNA_H
 // =========================================================================
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/multidim/instantiation.h>
 // =========================================================================
 #include <agrum/variables/discreteVariable.h>
@@ -51,7 +51,8 @@
 namespace gum {
 
   /**
-   * @class sdyna sdyna.h <agrum/FMDP/SDyna/sdyna.h>
+   * @class SDYNA
+   * @headerfile sdyna.h <agrum/FMDP/SDyna/sdyna.h>
    * @brief
    * @ingroup fmdp_group
    *
@@ -59,9 +60,7 @@ namespace gum {
    * Instance of SDyna architecture should inherit
    *
    */
-
   class SDYNA {
-
     // ###################################################################
     /// @name
     // ###################################################################
@@ -70,119 +69,119 @@ namespace gum {
     // ==========================================================================
     ///
     // ==========================================================================
-    static SDYNA* spitiInstance( double attributeSelectionThreshold = 0.99,
-                                 double discountFactor = 0.9,
-                                 double epsilon = 1,
-                                 Idx    observationPhaseLenght = 100,
-                                 Idx    nbValueIterationStep = 10 ) {
+    static SDYNA* spitiInstance(double attributeSelectionThreshold = 0.99,
+                                double discountFactor = 0.9,
+                                double epsilon = 1,
+                                Idx    observationPhaseLenght = 100,
+                                Idx    nbValueIterationStep = 10) {
       bool               actionReward = false;
-      ILearningStrategy* ls = new FMDPLearner<CHI2TEST, CHI2TEST, ITILEARNER>(
-          attributeSelectionThreshold, actionReward );
-      IPlanningStrategy<double>* ps =
-          StructuredPlaner<double>::sviInstance( discountFactor, epsilon );
+      ILearningStrategy* ls = new FMDPLearner< CHI2TEST, CHI2TEST, ITILEARNER >(
+        attributeSelectionThreshold, actionReward);
+      IPlanningStrategy< double >* ps =
+        StructuredPlaner< double >::sviInstance(discountFactor, epsilon);
       IDecisionStrategy* ds = new E_GreedyDecider();
       return new SDYNA(
-          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
+        ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward);
     }
 
     // ==========================================================================
     ///
     // ==========================================================================
-    static SDYNA* spimddiInstance( double attributeSelectionThreshold = 0.99,
-                                   double similarityThreshold = 0.3,
-                                   double discountFactor = 0.9,
-                                   double epsilon = 1,
-                                   Idx    observationPhaseLenght = 100,
-                                   Idx    nbValueIterationStep = 10 ) {
+    static SDYNA* spimddiInstance(double attributeSelectionThreshold = 0.99,
+                                  double similarityThreshold = 0.3,
+                                  double discountFactor = 0.9,
+                                  double epsilon = 1,
+                                  Idx    observationPhaseLenght = 100,
+                                  Idx    nbValueIterationStep = 10) {
       bool               actionReward = false;
-      ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, IMDDILEARNER>(
-          attributeSelectionThreshold, actionReward, similarityThreshold );
-      IPlanningStrategy<double>* ps = StructuredPlaner<double>::spumddInstance(
-          discountFactor, epsilon, false );
+      ILearningStrategy* ls = new FMDPLearner< GTEST, GTEST, IMDDILEARNER >(
+        attributeSelectionThreshold, actionReward, similarityThreshold);
+      IPlanningStrategy< double >* ps =
+        StructuredPlaner< double >::spumddInstance(discountFactor, epsilon, false);
       IDecisionStrategy* ds = new E_GreedyDecider();
-      return new SDYNA( ls,
-                        ps,
-                        ds,
-                        observationPhaseLenght,
-                        nbValueIterationStep,
-                        actionReward,
-                        false );
+      return new SDYNA(ls,
+                       ps,
+                       ds,
+                       observationPhaseLenght,
+                       nbValueIterationStep,
+                       actionReward,
+                       false);
     }
 
     // ==========================================================================
     ///
     // ==========================================================================
-    static SDYNA* RMaxMDDInstance( double attributeSelectionThreshold = 0.99,
-                                   double similarityThreshold = 0.3,
-                                   double discountFactor = 0.9,
-                                   double epsilon = 1,
-                                   Idx    observationPhaseLenght = 100,
-                                   Idx    nbValueIterationStep = 10 ) {
+    static SDYNA* RMaxMDDInstance(double attributeSelectionThreshold = 0.99,
+                                  double similarityThreshold = 0.3,
+                                  double discountFactor = 0.9,
+                                  double epsilon = 1,
+                                  Idx    observationPhaseLenght = 100,
+                                  Idx    nbValueIterationStep = 10) {
       bool               actionReward = true;
-      ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, IMDDILEARNER>(
-          attributeSelectionThreshold, actionReward, similarityThreshold );
-      AdaptiveRMaxPlaner* rm = AdaptiveRMaxPlaner::ReducedAndOrderedInstance(
-          ls, discountFactor, epsilon );
-      IPlanningStrategy<double>* ps = rm;
-      IDecisionStrategy*         ds = rm;
+      ILearningStrategy* ls = new FMDPLearner< GTEST, GTEST, IMDDILEARNER >(
+        attributeSelectionThreshold, actionReward, similarityThreshold);
+      AdaptiveRMaxPlaner* rm =
+        AdaptiveRMaxPlaner::ReducedAndOrderedInstance(ls, discountFactor, epsilon);
+      IPlanningStrategy< double >* ps = rm;
+      IDecisionStrategy*           ds = rm;
       return new SDYNA(
-          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
+        ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward);
     }
 
     // ==========================================================================
     ///
     // ==========================================================================
-    static SDYNA* RMaxTreeInstance( double attributeSelectionThreshold = 0.99,
+    static SDYNA* RMaxTreeInstance(double attributeSelectionThreshold = 0.99,
+                                   double discountFactor = 0.9,
+                                   double epsilon = 1,
+                                   Idx    observationPhaseLenght = 100,
+                                   Idx    nbValueIterationStep = 10) {
+      bool               actionReward = true;
+      ILearningStrategy* ls = new FMDPLearner< GTEST, GTEST, ITILEARNER >(
+        attributeSelectionThreshold, actionReward);
+      AdaptiveRMaxPlaner* rm =
+        AdaptiveRMaxPlaner::TreeInstance(ls, discountFactor, epsilon);
+      IPlanningStrategy< double >* ps = rm;
+      IDecisionStrategy*           ds = rm;
+      return new SDYNA(
+        ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward);
+    }
+
+    // ==========================================================================
+    ///
+    // ==========================================================================
+    static SDYNA* RandomMDDInstance(double attributeSelectionThreshold = 0.99,
+                                    double similarityThreshold = 0.3,
                                     double discountFactor = 0.9,
                                     double epsilon = 1,
                                     Idx    observationPhaseLenght = 100,
-                                    Idx    nbValueIterationStep = 10 ) {
+                                    Idx    nbValueIterationStep = 10) {
       bool               actionReward = true;
-      ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, ITILEARNER>(
-          attributeSelectionThreshold, actionReward );
-      AdaptiveRMaxPlaner* rm =
-          AdaptiveRMaxPlaner::TreeInstance( ls, discountFactor, epsilon );
-      IPlanningStrategy<double>* ps = rm;
-      IDecisionStrategy*         ds = rm;
+      ILearningStrategy* ls = new FMDPLearner< GTEST, GTEST, IMDDILEARNER >(
+        attributeSelectionThreshold, actionReward, similarityThreshold);
+      IPlanningStrategy< double >* ps =
+        StructuredPlaner< double >::spumddInstance(discountFactor, epsilon);
+      IDecisionStrategy* ds = new RandomDecider();
       return new SDYNA(
-          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
+        ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward);
     }
 
     // ==========================================================================
     ///
     // ==========================================================================
-    static SDYNA* RandomMDDInstance( double attributeSelectionThreshold = 0.99,
-                                     double similarityThreshold = 0.3,
+    static SDYNA* RandomTreeInstance(double attributeSelectionThreshold = 0.99,
                                      double discountFactor = 0.9,
                                      double epsilon = 1,
                                      Idx    observationPhaseLenght = 100,
-                                     Idx    nbValueIterationStep = 10 ) {
+                                     Idx    nbValueIterationStep = 10) {
       bool               actionReward = true;
-      ILearningStrategy* ls = new FMDPLearner<GTEST, GTEST, IMDDILEARNER>(
-          attributeSelectionThreshold, actionReward, similarityThreshold );
-      IPlanningStrategy<double>* ps =
-          StructuredPlaner<double>::spumddInstance( discountFactor, epsilon );
+      ILearningStrategy* ls = new FMDPLearner< CHI2TEST, CHI2TEST, ITILEARNER >(
+        attributeSelectionThreshold, actionReward);
+      IPlanningStrategy< double >* ps =
+        StructuredPlaner< double >::sviInstance(discountFactor, epsilon);
       IDecisionStrategy* ds = new RandomDecider();
       return new SDYNA(
-          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
-    }
-
-    // ==========================================================================
-    ///
-    // ==========================================================================
-    static SDYNA* RandomTreeInstance( double attributeSelectionThreshold = 0.99,
-                                      double discountFactor = 0.9,
-                                      double epsilon = 1,
-                                      Idx    observationPhaseLenght = 100,
-                                      Idx    nbValueIterationStep = 10 ) {
-      bool               actionReward = true;
-      ILearningStrategy* ls = new FMDPLearner<CHI2TEST, CHI2TEST, ITILEARNER>(
-          attributeSelectionThreshold, actionReward );
-      IPlanningStrategy<double>* ps =
-          StructuredPlaner<double>::sviInstance( discountFactor, epsilon );
-      IDecisionStrategy* ds = new RandomDecider();
-      return new SDYNA(
-          ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward );
+        ls, ps, ds, observationPhaseLenght, nbValueIterationStep, actionReward);
     }
 
 
@@ -201,13 +200,13 @@ namespace gum {
      */
     // ==========================================================================
     private:
-    SDYNA( ILearningStrategy*         learner,
-           IPlanningStrategy<double>* planer,
-           IDecisionStrategy*         decider,
-           Idx                        observationPhaseLenght,
-           Idx                        nbValueIterationStep,
-           bool                       actionReward,
-           bool                       verbose = true );
+    SDYNA(ILearningStrategy*           learner,
+          IPlanningStrategy< double >* planer,
+          IDecisionStrategy*           decider,
+          Idx                          observationPhaseLenght,
+          Idx                          nbValueIterationStep,
+          bool                         actionReward,
+          bool                         verbose = true);
 
     // ==========================================================================
     /// Destructor
@@ -231,8 +230,8 @@ namespace gum {
      * @param actionName : its human name
      */
     // ==========================================================================
-    void addAction( const Idx actionId, const std::string& actionName ) {
-      _fmdp->addAction( actionId, actionName );
+    void addAction(const Idx actionId, const std::string& actionName) {
+      _fmdp->addAction(actionId, actionName);
     }
 
     // ==========================================================================
@@ -245,7 +244,7 @@ namespace gum {
      * process
      */
     // ==========================================================================
-    void addVariable( const DiscreteVariable* var ) { _fmdp->addVariable( var ); }
+    void addVariable(const DiscreteVariable* var) { _fmdp->addVariable(var); }
 
     /// @}
 
@@ -269,7 +268,7 @@ namespace gum {
      * begin the explore, learn and exploit process
      */
     // ==========================================================================
-    void initialize( const Instantiation& initialState );
+    void initialize(const Instantiation& initialState);
 
     /// @}
 
@@ -287,7 +286,7 @@ namespace gum {
      * @param currentState : the state
      */
     // ==========================================================================
-    void setCurrentState( const Instantiation& currentState ) {
+    void setCurrentState(const Instantiation& currentState) {
       _lastState = currentState;
     }
 
@@ -298,7 +297,7 @@ namespace gum {
      * @param curState the state in which we currently are
      */
     // ==========================================================================
-    Idx takeAction( const Instantiation& curState );
+    Idx takeAction(const Instantiation& curState);
 
     // ==========================================================================
     /**
@@ -317,10 +316,10 @@ namespace gum {
      * @param obtainedReward : the reward we obtained
      */
     // ==========================================================================
-    void feedback( const Instantiation& originalState,
-                   const Instantiation& reachedState,
-                   Idx                  performedAction,
-                   double               obtainedReward );
+    void feedback(const Instantiation& originalState,
+                  const Instantiation& reachedState,
+                  Idx                  performedAction,
+                  double               obtainedReward);
 
     // ==========================================================================
     /**
@@ -333,7 +332,7 @@ namespace gum {
      * below
      */
     // ==========================================================================
-    void feedback( const Instantiation& reachedState, double obtainedReward );
+    void feedback(const Instantiation& reachedState, double obtainedReward);
 
     // ==========================================================================
     /**
@@ -342,7 +341,7 @@ namespace gum {
      * planning
      */
     // ==========================================================================
-    void makePlanning( Idx nbStep );
+    void makePlanning(Idx nbStep);
 
     /// @}
 
@@ -405,7 +404,7 @@ namespace gum {
 
     protected:
     /// The learnt Markovian Decision Process
-    FMDP<double>* _fmdp;
+    FMDP< double >* _fmdp;
 
     /// The state in which the system is before we perform a new action
     Instantiation _lastState;
@@ -415,7 +414,7 @@ namespace gum {
     ILearningStrategy* __learner;
 
     /// The planer used to plan an optimal strategy
-    IPlanningStrategy<double>* __planer;
+    IPlanningStrategy< double >* __planer;
 
     /// The decider
     IDecisionStrategy* __decider;
@@ -434,7 +433,7 @@ namespace gum {
     Idx __lastAction;
 
     /// Since SDYNA made these observation, it has to delete them on quitting
-    Set<Observation*> __bin;
+    Set< Observation* > __bin;
 
     bool __actionReward;
 
@@ -445,6 +444,4 @@ namespace gum {
 } /* namespace gum */
 
 
-#endif  // GUM_SDYNA_H
-
-// kate: indent-mode cstyle; indent-width 2; replace-tabs on; ;
+#endif   // GUM_SDYNA_H
