@@ -33,7 +33,7 @@
 // =========================================================================
 #include <agrum/graphs/parts/nodeGraphPart.h>
 // =========================================================================
-#include <agrum/multidim/multiDimFunctionGraph.h>
+#include <agrum/multidim/implementations/multiDimFunctionGraph.h>
 // =========================================================================
 #include <agrum/variables/discreteVariable.h>
 // =========================================================================
@@ -48,7 +48,6 @@ namespace gum {
    *
    */
   class IVisitableGraphLearner {
-
     // ###################################################################
     /// @name Constructor & destructor.
     // ###################################################################
@@ -75,27 +74,27 @@ namespace gum {
     // ==========================================================================
     ///
     // ==========================================================================
-    virtual bool isTerminal( NodeId ni ) const = 0;
+    virtual bool isTerminal(NodeId ni) const = 0;
 
     // ==========================================================================
     ///
     // ==========================================================================
-    virtual const DiscreteVariable* nodeVar( NodeId ni ) const = 0;
+    virtual const DiscreteVariable* nodeVar(NodeId ni) const = 0;
 
     // ==========================================================================
     ///
     // ==========================================================================
-    virtual NodeId nodeSon( NodeId ni, Idx modality ) const = 0;
+    virtual NodeId nodeSon(NodeId ni, Idx modality) const = 0;
 
     // ==========================================================================
     ///
     // ==========================================================================
-    virtual Idx nodeNbObservation( NodeId ni ) const = 0;
+    virtual Idx nodeNbObservation(NodeId ni) const = 0;
 
-    virtual void insertSetOfVars( MultiDimFunctionGraph<double>* ) const = 0;
+    virtual void insertSetOfVars(MultiDimFunctionGraph< double >*) const = 0;
 
 
     /// @}
   };
-}
-#endif  // GUM_INTERFACE_VISITABLE_GRAPH_LEARNER_H
+}   // namespace gum
+#endif   // GUM_INTERFACE_VISITABLE_GRAPH_LEARNER_H
