@@ -33,7 +33,7 @@
 #include <type_traits>
 #include <utility>
 
-#include <agrum/config.h>
+#include <agrum/agrum.h>
 #include <agrum/core/refPtr.h>
 
 namespace gum {
@@ -53,10 +53,11 @@ namespace gum {
    * @return Returns the size in bits - 1 necessary to store the smallest power
    * of 2 greater than or equal to nb.
    */
-  unsigned int __hashTableLog2( const Size& nb );
+  unsigned int __hashTableLog2(const Size& nb);
 
   /**
-   * @class HashFuncConst hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncConst
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @ingroup hashfunctions_group
    * @brief Constants for hash functions.
    *
@@ -70,24 +71,25 @@ namespace gum {
    * should adapt X's definition to 32 and 64 bits architectures.
    * */
   struct HashFuncConst {
-#if ULONG_MAX == 4294967295UL  // unsigned long = 32 bits
+#if ULONG_MAX == 4294967295UL   // unsigned long = 32 bits
     static constexpr unsigned long gold = 2654435769UL;
     static constexpr unsigned long pi = 3373259426UL;
     static constexpr unsigned long mask = 4294967295UL;
     static constexpr size_t        offset = 32;
-#else  // unsigned long = 64 bits
+#else   // unsigned long = 64 bits
     static constexpr unsigned long gold = 11400714819323198486UL;
     static constexpr unsigned long pi = 14488038916154245684UL;
     static constexpr unsigned long mask = 18446744073709551615UL;
     static constexpr size_t        offset = 64;
-#endif /* unsigned long = 32 bits */
+#endif  /* unsigned long = 32 bits */
   };
 
   // ===========================================================================
   // ===             BASE CLASS SHARED BY ALL THE HASH FUNCTIONS             ===
   // ===========================================================================
   /**
-   * @class HashFuncBase hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncBase
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief All hash functions should inherit from this class.
    * @ingroup hashfunctions_group
    *
@@ -144,7 +146,7 @@ namespace gum {
    *
    * @tparam Key The type hashed by this hash function.
    */
-  template <typename Key>
+  template < typename Key >
   class HashFuncBase {
     public:
     /**
@@ -158,18 +160,19 @@ namespace gum {
      * array of lists, not the number of elements stored into the
      * gum::HashTable.
      *
-     * @param s The hashtable's size wished by the user. Actually, a hashtable
+     * @param new_size The hashtable's size wished by the user. Actually, a
+     * hashtable
      * of size n is an array of n lists.
      * @throw SizeError Raised if s is too small.
      */
-    virtual void resize( Size s );
+    virtual void resize(Size new_size);
 
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    virtual Size operator()( const Key& key ) const = 0;
+    virtual Size operator()(const Key& key) const = 0;
 
     /**
      * @brief Returns the hash table size as known by the hash function.
@@ -196,17 +199,18 @@ namespace gum {
   // ===========================================================================
 
   /**
-   * @class HashFuncSmallKey hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncSmallKey
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Generic hash functions for keys smaller than or equal to long
    * integers.
    * @ingroup hashfunctions_group
    * @tparam Key The type hashed by this hash function.
    */
-  template <typename Key>
-  class HashFuncSmallKey : private HashFuncBase<Key> {
+  template < typename Key >
+  class HashFuncSmallKey : private HashFuncBase< Key > {
     public:
     /// This class use the HashFuncBase::size.
-    using HashFuncBase<Key>::size;
+    using HashFuncBase< Key >::size;
 
     /**
      * @brief Update the hash function to take into account a resize of the
@@ -219,18 +223,19 @@ namespace gum {
      * array of lists, not the number of elements stored into the
      * gum::HashTable.
      *
-     * @param s The hashtable's size wished by the user. Actually, a hashtable
+     * @param new_size The hashtable's size wished by the user. Actually, a
+     * hashtable
      * of size n is an array of n lists.
      * @throw SizeError Raised if s is too small.
      */
-    void resize( Size s );
+    void resize(Size new_size) override;
 
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const Key& key ) const;
+    Size operator()(const Key& key) const override;
 
     protected:
     /// The number of right shift to perform to get correct hashed values.
@@ -238,14 +243,15 @@ namespace gum {
   };
 
   /**
-   * @class HashFuncSmallCastKey hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncSmallCastKey
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Generic hash functions for keys castable as unsigned longs and
    * whose size is strictly smaller than that of unsigned longs.
    * @ingroup hashfunctions_group
    * @tparam Key The type hashed by this hash function.
    */
-  template <typename Key>
-  class HashFuncSmallCastKey : private HashFuncBase<Key> {
+  template < typename Key >
+  class HashFuncSmallCastKey : private HashFuncBase< Key > {
     public:
     /**
      * @brief Class constructor.
@@ -263,25 +269,26 @@ namespace gum {
      * array of lists, not the number of elements stored into the
      * gum::HashTable.
      *
-     * @param s The hashtable's size wished by the user. Actually, a hashtable
+     * @param new_size The hashtable's size wished by the user. Actually, a
+     * hashtable
      * of size n is an array of n lists.
      * @throw SizeError Raised if s is too small.
      */
-    void resize( Size s );
+    void resize(Size new_size) override;
 
     /**
      * @brief Returns the value of a key as an unsigned long.
      * @param key The value to return as an unsigned long.
      * @return Returns the value of a key as an unsigned long.
      */
-    Size castToSize( const Key& key ) const;
+    Size castToSize(const Key& key) const;
 
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const Key& key ) const;
+    Size operator()(const Key& key) const override;
 
     protected:
     /// The number of right shift to perform to get correct hashed values.
@@ -295,17 +302,18 @@ namespace gum {
   };
 
   /**
-   * @class HashFuncMediumCastKey hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncMediumCastKey
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Generic hash functions for keys castable as unsigned longs and
    * whose size is precisely that of unsigned longs.
    * @ingroup hashfunctions_group
    * @tparam Key The type hashed by this hash function.
    */
-  template <typename Key>
-  class HashFuncMediumCastKey : private HashFuncBase<Key> {
+  template < typename Key >
+  class HashFuncMediumCastKey : private HashFuncBase< Key > {
     public:
     /// This class use the HashFuncBase::size.
-    using HashFuncBase<Key>::size;
+    using HashFuncBase< Key >::size;
 
     /**
      * @brief Update the hash function to take into account a resize of the
@@ -318,25 +326,26 @@ namespace gum {
      * array of lists, not the number of elements stored into the
      * gum::HashTable.
      *
-     * @param s The hashtable's size wished by the user. Actually, a hashtable
+     * @param new_size The hashtable's size wished by the user. Actually, a
+     * hashtable
      * of size n is an array of n lists.
      * @throw SizeError Raised if s is too small.
      */
-    void resize( Size s );
+    void resize(Size new_size) override;
 
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const Key& key ) const;
+    Size operator()(const Key& key) const override;
 
     /**
      * @brief Returns the value of a key as an unsigned long.
      * @param key The value to return as an unsigned long.
      * @return Returns the value of a key as an unsigned long.
      */
-    Size castToSize( const Key& key ) const;
+    Size castToSize(const Key& key) const;
 
 
     protected:
@@ -345,17 +354,18 @@ namespace gum {
   };
 
   /**
-   * @class HashFuncLargeCastKey hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncLargeCastKey
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Generic hash functions for keys castable as unsigned longs and
    * whose size is precisely twice that of unsigned longs.
    * @ingroup hashfunctions_group
    * @tparam Key The type hashed by this hash function.
    */
-  template <typename Key>
-  class HashFuncLargeCastKey : private HashFuncBase<Key> {
+  template < typename Key >
+  class HashFuncLargeCastKey : private HashFuncBase< Key > {
     public:
     /// This class use the HashFuncBase::size.
-    using HashFuncBase<Key>::size;
+    using HashFuncBase< Key >::size;
 
     /**
      * @brief Update the hash function to take into account a resize of the
@@ -368,61 +378,44 @@ namespace gum {
      * array of lists, not the number of elements stored into the
      * gum::HashTable.
      *
-     * @param s The hashtable's size wished by the user. Actually, a hashtable
+     * @param new_size The hashtable's size wished by the user. Actually, a
+     * hashtable
      * of size n is an array of n lists.
      * @throw SizeError Raised if s is too small.
      */
-    void resize( Size s );
+    void resize(Size new_size) override;
 
     /**
      * @brief Cast key to the exepcted type.
      * @param key The key to cast.
      * @return Returns the cast key to the exepcted type.
      */
-    Size castToSize( const Key& key ) const;
+    Size castToSize(const Key& key) const;
 
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const Key& key ) const;
+    Size operator()(const Key& key) const;
 
     protected:
     /// The number of right shift to perform to get correct hashed values.
     unsigned int _right_shift;
   };
 
-  /**
-   * @class HashFuncCastKey hashFunc.h <agrum/core/hashFunc.h>
-   * @brief Generic hash functions for keys castable as unsigned longs whose
-   * size is either smaller than unsigned long, or equal to that of one or two
-   * unsigned longs.
-   * @ingroup hashfunctions_group
-   * @tparam Key The type hashed by this hash function.
-   */
-  template <typename T>
-  struct HashFuncCastKey {
-
-    /// The type used by this class.
-    using type = typename std::conditional<
-        sizeof( T ) < sizeof( long ),
-        HashFuncSmallCastKey<T>,
-        typename std::conditional<sizeof( T ) == 2 * sizeof( long ),
-                                  HashFuncLargeCastKey<T>,
-                                  HashFuncMediumCastKey<T>>::type>::type;
-  };
 
   /**
-   * @class HashFuncSmallKeyPair hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncSmallKeyPair
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Generic hash functions for pairs of, at most, two long integer
    * keys.
    * @ingroup hashfunctions_group
    * @tparam Key1 The type hashed of the first element in the pair.
    * @tparam Key2 The type hashed of the second element in the pair.
    */
-  template <typename Key1, typename Key2>
-  class HashFuncSmallKeyPair : public HashFuncBase<std::pair<Key1, Key2>> {
+  template < typename Key1, typename Key2 >
+  class HashFuncSmallKeyPair : public HashFuncBase< std::pair< Key1, Key2 > > {
     public:
     /**
      * @brief Update the hash function to take into account a resize of the
@@ -435,18 +428,19 @@ namespace gum {
      * array of lists, not the number of elements stored into the
      * gum::HashTable.
      *
-     * @param s The hashtable's size wished by the user. Actually, a hashtable
+     * @param new_size The hashtable's size wished by the user. Actually, a
+     * hashtable
      * of size n is an array of n lists.
      * @throw SizeError Raised if s is too small.
      */
-    void resize( Size s );
+    void resize(Size new_size) override;
 
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const std::pair<Key1, Key2>& key ) const;
+    Size operator()(const std::pair< Key1, Key2 >& key) const override;
 
     protected:
     /// The number of right shift to perform to get correct hashed values.
@@ -454,7 +448,8 @@ namespace gum {
   };
 
   /**
-   * @class HashFuncAllCastKeyPair hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncAllCastKeyPair
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Generic hash functions for pairs of keys whose sizes are precisely
    * twice that of unsigned longs and which can be cast into unsigned longs.
    * @ingroup hashfunctions_group
@@ -463,8 +458,8 @@ namespace gum {
    * @tparam Func1 The function to hash Key1.
    * @tparam Func2 The function to hash Key2.
    */
-  template <typename Key1, typename Key2, typename Func1, typename Func2>
-  class HashFuncAllCastKeyPair : public HashFuncBase<std::pair<Key1, Key2>> {
+  template < typename Key1, typename Key2, typename Func1, typename Func2 >
+  class HashFuncAllCastKeyPair : public HashFuncBase< std::pair< Key1, Key2 > > {
     public:
     /**
      * @brief Update the hash function to take into account a resize of the
@@ -477,18 +472,19 @@ namespace gum {
      * array of lists, not the number of elements stored into the
      * gum::HashTable.
      *
-     * @param s The hashtable's size wished by the user. Actually, a hashtable
+     * @param new_size The hashtable's size wished by the user. Actually, a
+     * hashtable
      * of size n is an array of n lists.
      * @throw SizeError Raised if s is too small.
      */
-    void resize( Size s );
+    void resize(Size new_size) override;
 
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const std::pair<Key1, Key2>& key ) const;
+    Size operator()(const std::pair< Key1, Key2 >& key) const override;
 
     protected:
     /// The number of right shift to perform to get correct hashed values.
@@ -501,32 +497,109 @@ namespace gum {
     Func2 __func2;
   };
 
+
+  // ===========================================================================
+  // ===         GENERAL HASH FUNCTIONS CASTING AND CONDITIONAL TYPES        ===
+  // ===========================================================================
+
   /**
-   * @class HashFuncCastKeyPair hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFuncCastKey
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Generic hash functions for keys castable as unsigned longs whose
    * size is either smaller than unsigned long, or equal to that of one or two
    * unsigned longs.
    * @ingroup hashfunctions_group
    * @tparam Key The type hashed by this hash function.
    */
-  template <typename T1, typename T2>
+  template < typename T >
+  struct HashFuncCastKey {
+    /// The type used by this class.
+    using type = typename std::conditional<
+      sizeof(T) < sizeof(long),
+      HashFuncSmallCastKey< T >,
+      typename std::conditional< sizeof(T) == 2 * sizeof(long),
+                                 HashFuncLargeCastKey< T >,
+                                 HashFuncMediumCastKey< T > >::type >::type;
+  };
+
+
+  /**
+   * @class HashFuncCastKeyPair
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
+   * @brief Generic hash functions for keys castable as unsigned longs whose
+   * size is either smaller than unsigned long, or equal to that of one or two
+   * unsigned longs.
+   * @ingroup hashfunctions_group
+   * @tparam Key The type hashed by this hash function.
+   */
+  template < typename T1, typename T2 >
   struct HashFuncCastKeyPair {
     /// The casting function for T1.
-    using Func1 = typename HashFuncCastKey<T1>::type;
+    using Func1 = typename HashFuncCastKey< T1 >::type;
 
     /// The casting function for T2.
-    using Func2 = typename HashFuncCastKey<T2>::type;
+    using Func2 = typename HashFuncCastKey< T2 >::type;
 
     /// The expected type of this class.
-    using type = HashFuncAllCastKeyPair<T1, T2, Func1, Func2>;
+    using type = HashFuncAllCastKeyPair< T1, T2, Func1, Func2 >;
   };
 
+
+  template < typename T >
+  class dummyHash {};
+
+  template < typename... >
+  struct HashFuncConditionalType;
+
+  template < typename HASH_TYPE >
+  struct HashFuncConditionalType< HASH_TYPE > {
+    using type = HASH_TYPE;
+  };
+
+  template < typename HASH_TYPE, typename TYPE >
+  struct HashFuncConditionalType< HASH_TYPE, TYPE > {
+    using type = typename std::conditional< std::is_same< HASH_TYPE, TYPE >::value,
+                                            dummyHash< HASH_TYPE >,
+                                            HASH_TYPE >::type;
+  };
+
+  /**
+   * @class HashFuncConditionalType
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
+   * @brief This class enables to safely define hash functions for types
+   * that may or may not already has defined hash functions
+   * @ingroup hashfunctions_group
+   *
+   * There are types that are defined differently depending on the architecture
+   * or the compiler you use. This is the case, for instance, of std::size_t
+   * which is defined as an unsigned long by gcc and clang on 64 bits
+   * architectures, but is defined as an unsigned int in 32 bits architectures by
+   * theses compilers, and it is defined neither as an unsigned long nor as
+   * an unsigned int by Visual Studio 15 MVSC on 64 bits architectures. To
+   * enable to define the hash function of std::size_t appropriately in all these
+   * cases, instead of defining directly a HasHunc of <std::size_t>, it is
+   * sufficient to define a HashFunc of
+   * <HashFuncConditionalType<std::size_t,unsigned int,unsigned long>::type>.
+   * The latter will actually define a HasHunc of <std::size_t> if size_t
+   * corresponds neither to an unsigned int nor to an unsigned long, else it
+   * will not define the HasHunc of <std::size_t> (which would redefine an
+   * already defined HashFunc, hence resulting in a compilation failure). */
+  template < typename HASH_TYPE, typename FIRST_TYPE, typename... OTHER_TYPES >
+  struct HashFuncConditionalType< HASH_TYPE, FIRST_TYPE, OTHER_TYPES... > {
+    using type = typename std::conditional<
+      std::is_same< HASH_TYPE, FIRST_TYPE >::value,
+      dummyHash< HASH_TYPE >,
+      typename HashFuncConditionalType< HASH_TYPE, OTHER_TYPES... >::type >::type;
+  };
+
+
   // ===========================================================================
   // ===                      WIDELY USED HASH FUNCTIONS                     ===
   // ===========================================================================
 
   /**
-   * @class HashFunc hashFunc.h <agrum/core/hashFunc.h>
+   * @class HashFunc
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief This class should be useless as only its specializations should be
    * used.
    *
@@ -535,7 +608,7 @@ namespace gum {
    *
    * @ingroup hashfunctions_group
    */
-  template <typename key>
+  template < typename key >
   class HashFunc {};
 
   /**
@@ -544,7 +617,7 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<bool> : public HashFuncSmallKey<bool> {};
+  class HashFunc< bool > : public HashFuncSmallKey< bool > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -552,7 +625,7 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<int> : public HashFuncSmallKey<int> {};
+  class HashFunc< int > : public HashFuncSmallKey< int > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -560,7 +633,7 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<unsigned int> : public HashFuncSmallKey<unsigned int> {};
+  class HashFunc< unsigned int > : public HashFuncSmallKey< unsigned int > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -568,7 +641,7 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<long> : public HashFuncSmallKey<long> {};
+  class HashFunc< long > : public HashFuncSmallKey< long > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -576,7 +649,20 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<unsigned long> : public HashFuncSmallKey<unsigned long> {};
+  class HashFunc< unsigned long > : public HashFuncSmallKey< unsigned long > {};
+
+  /**
+   * @headerfile hashFunc.h <agrum/core/hashFunc.h>
+   * @brief Hash function for std::size_t.
+   * @ingroup hashfunctions_group
+   */
+  template <>
+  class HashFunc< typename HashFuncConditionalType< std::size_t,
+                                                    unsigned long,
+                                                    unsigned int,
+                                                    long,
+                                                    int >::type >
+      : public HashFuncCastKey< std::size_t >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -584,7 +670,7 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<float> : public HashFuncCastKey<float>::type {};
+  class HashFunc< float > : public HashFuncCastKey< float >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -592,15 +678,15 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<double> : public HashFuncCastKey<double>::type {};
+  class HashFunc< double > : public HashFuncCastKey< double >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
    * @brief Hash function for pointers.
    * @tparam The type for which the pointer is used to compute a hash.
    */
-  template <typename Type>
-  class HashFunc<Type*> : public HashFuncCastKey<Type*>::type {};
+  template < typename Type >
+  class HashFunc< Type* > : public HashFuncCastKey< Type* >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -608,7 +694,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<int, int>> : public HashFuncSmallKeyPair<int, int> {};
+  class HashFunc< std::pair< int, int > >
+      : public HashFuncSmallKeyPair< int, int > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -616,8 +703,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<unsigned int, unsigned int>>
-      : public HashFuncSmallKeyPair<unsigned int, unsigned int> {};
+  class HashFunc< std::pair< unsigned int, unsigned int > >
+      : public HashFuncSmallKeyPair< unsigned int, unsigned int > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -625,8 +712,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<long, long>> : public HashFuncSmallKeyPair<long, long> {
-  };
+  class HashFunc< std::pair< long, long > >
+      : public HashFuncSmallKeyPair< long, long > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -634,8 +721,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<unsigned long, unsigned long>>
-      : public HashFuncSmallKeyPair<unsigned long, unsigned long> {};
+  class HashFunc< std::pair< unsigned long, unsigned long > >
+      : public HashFuncSmallKeyPair< unsigned long, unsigned long > {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -643,8 +730,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<float, float>>
-      : public HashFuncCastKeyPair<float, float>::type {};
+  class HashFunc< std::pair< float, float > >
+      : public HashFuncCastKeyPair< float, float >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -652,8 +739,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<double, double>>
-      : public HashFuncCastKeyPair<float, float>::type {};
+  class HashFunc< std::pair< double, double > >
+      : public HashFuncCastKeyPair< float, float >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -661,8 +748,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<double, long unsigned int>>
-      : public HashFuncCastKeyPair<double, long unsigned int>::type {};
+  class HashFunc< std::pair< double, long unsigned int > >
+      : public HashFuncCastKeyPair< double, long unsigned int >::type {};
 
   /**
    * @author JCM
@@ -673,8 +760,8 @@ namespace gum {
    * @ingroup HashF
    */
   template <>
-  class HashFunc<std::pair<long unsigned int, double>>
-      : public HashFuncCastKeyPair<long unsigned int, double>::type {};
+  class HashFunc< std::pair< long unsigned int, double > >
+      : public HashFuncCastKeyPair< long unsigned int, double >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -682,8 +769,8 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<double, long int>>
-      : public HashFuncCastKeyPair<double, long int>::type {};
+  class HashFunc< std::pair< double, long int > >
+      : public HashFuncCastKeyPair< double, long int >::type {};
 
   /**
    * @headerfile hashFunc.h <agrum/core/hashFunc.h>
@@ -691,15 +778,15 @@ namespace gum {
    * @ingroup hashfunctions_group
    * @tparam Type The type of the RefPtr.
    */
-  template <typename Type>
-  class HashFunc<RefPtr<Type>> : public HashFunc<unsigned int*> {
+  template < typename Type >
+  class HashFunc< RefPtr< Type > > : public HashFunc< unsigned int* > {
     public:
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const RefPtr<Type>& key ) const;
+    Size operator()(const RefPtr< Type >& key) const;
   };
 
   /**
@@ -708,14 +795,14 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::string> : public HashFuncBase<std::string> {
+  class HashFunc< std::string > : public HashFuncBase< std::string > {
     public:
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const std::string& key ) const;
+    Size operator()(const std::string& key) const override;
   };
 
   /**
@@ -724,15 +811,15 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::pair<std::string, std::string>>
-      : public HashFuncBase<std::pair<std::string, std::string>> {
+  class HashFunc< std::pair< std::string, std::string > >
+      : public HashFuncBase< std::pair< std::string, std::string > > {
     public:
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const std::pair<std::string, std::string>& key ) const;
+    Size operator()(const std::pair< std::string, std::string >& key) const;
   };
 
   /**
@@ -741,14 +828,15 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<std::vector<Idx>> : public HashFuncBase<std::vector<Idx>> {
+  class HashFunc< std::vector< Idx > >
+      : public HashFuncBase< std::vector< Idx > > {
     public:
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const std::vector<Idx>& key ) const;
+    Size operator()(const std::vector< Idx >& key) const;
   };
 
   /**
@@ -757,21 +845,20 @@ namespace gum {
    * @ingroup hashfunctions_group
    */
   template <>
-  class HashFunc<Debug> : public HashFuncBase<Debug> {
+  class HashFunc< Debug > : public HashFuncBase< Debug > {
     public:
     /**
      * @brief Computes the hashed value of a key.
      * @param key The key to compute the hashed value.
      * @return Returns the hashed value of a key.
      */
-    Size operator()( const Debug& key ) const;
+    Size operator()(const Debug& key) const;
   };
-
 } /* namespace gum */
 
 /// include the inlined functions if necessary
 #ifndef GUM_NO_INLINE
-#include <agrum/core/hashFunc_inl.h>
+#  include <agrum/core/hashFunc_inl.h>
 #endif /* GUM_NO_INLINE */
 
 /// always include the implementation of the templates
